#!/usr/bin/env python
# -*- coding: iso-8859-1 -*-

"An OpenID login example with some local user pages."

from WebStack.Resources.OpenIDLogin import OpenIDLoginResource, Authenticator
from WebStack.Resources.ResourceMap import MapResource
from WebStack.Resources.Static import StringResource
from WebStack.Generic import ContentType

def get_site_map(app_url):

    "Return a resource for the site having the given 'app_url'."

    return MapResource({
        "login" :
            OpenIDLoginResource(
                app_url=app_url,
                authenticator=Authenticator(
                    credentials=(
                        # Local identifier,    username,  password
                        ((app_url + "/badger", "badger"), "abc"),
                        ((app_url + "/vole",   "vole"),   "xyz"),
                        ((app_url + u"/",   u""),   u""),
                    )
                )
            ),

        # Some local OpenID pages.

        "badger" :
            StringResource("""
                <html>
                  <head>
                    <link rel="openid2.provider openid.server" href="%s/login" />
                    <link rel="openid2.local_id openid.delegate" href="%s/badger" />
                    <title>Badger's Home Page</title>
                  </head>
                  <body>
                    <p>Home page for the OpenID authenticated user, <code>badger</code>.</p>
                  </body>
                </html>
            """ % (app_url, app_url), ContentType("text/html")),
        u"" :
            StringResource(u"""
                <html>
                  <head>
                    <link rel="openid2.provider openid.server" href="%s/login" />
                    <link rel="openid2.local_id openid.delegate" href="%s/" />
                    <title>Home Page for </title>
                  </head>
                  <body>
                    <p>Home page for the OpenID authenticated user, <code></code>.</p>
                  </body>
                </html>
            """ % (app_url, app_url), ContentType("text/html", "iso-8859-1")),
        "vole" :
            StringResource("""
                <html>
                  <head>
                    <link rel="openid2.provider openid.server" href="%s/login" />
                    <link rel="openid2.local_id openid.delegate" href="%s/vole" />
                    <title>Vole's Home Page</title>
                  </head>
                  <body>
                    <p>Home page for the OpenID authenticated user, <code>vole</code>.</p>
                  </body>
                </html>
            """ % (app_url, app_url), ContentType("text/html"))
        })

# vim: tabstop=4 expandtab shiftwidth=4
